#
# spec file for package cutecom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cutecom
Version:        0.60.0
Release:        1.4
Summary:        A graphical serial terminal
License:        GPL-3.0-or-later
Group:          System/X11/Terminals
URL:            https://gitlab.com/cutecom/cutecom
Source:         https://gitlab.com/%{name}/%{name}/-/archive/v%{version}-RC1/%{name}-v%{version}-RC1.tar.bz2
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6SerialPort)
BuildRequires:  cmake(Qt6Widgets)

%description
CuteCom is a graphical serial terminal, similar to minicom. It is
written using the Qt library.

It is aimed mainly at hardware developers or other people who need a
terminal to talk to their devices.

%prep
%autosetup -n %{name}-v%{version}-RC1

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc Changelog TODO CREDITS README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/metainfo/com.gitlab.%{name}.%{name}.appdata.xml

%changelog
* Wed Jun 12 2024 Dirk Stoecker <opensuse@dstoecker.de>
- update to 0.60. (RC1) - support Qt6
- Drop 0001-Fix-build-with-Qt-5.15.patch (included upstream)
* Fri Jun  5 2020 Martin Pluskal <mpluskal@suse.com>
- Small packaging adjustements:
  * Dont manually compress manpages
  * Fully leverage install command
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.patch
- Spec cleanup
* Sat Sep  1 2018 cyc1ingsir@gmail.com
-update to release 0.51.0
  * moved to a new home
  * added auto reconnect feature
  - ------------------------------------------------------------------
* Mon Aug  6 2018 cyc1ingsir@gmail.com
-update to release 0.50.0
  * added the byte counter plugin
  * added a plugin manager
  * added macros plugin to support similar to br@y's terminal
  * added netproxy plugin
  * improved logfile handling
  * redesign control panel's opening button
* Sun Jun 17 2018 cyc1ingsir@gmail.com
-update to release 0.45.0
  * Enable input of Crl characters using a popup or Ctrl+<x>
  * Windows support added
  * line termination was not saved in settings - FIX
  * upgrading to clang-format to version 3.8.0
  * updating travis ci instructions - FIX
  * support for Qt5>=5.11
* Mon Jun 11 2018 opensuse@dstoecker.de
- fix build with cmake >= 5.11 (68.patch)
* Sat Aug 12 2017 jengelh@inai.de
- Trim redundant info from description that is already part of the
  spec preamble.
* Thu Aug  3 2017 opensuse@dstoecker.de
- update to 0.40.0
  - First implementation of searching the output
  - Linked line termination of displayed data
  with the option (LF, CRLF, CR, ...) for user input.
  - compress/combine multiple non printable characters into one expression
  in case the same non printable characters is beeing received multiple
  times in a sequence
  - enable a mix from hex and ascii characters in hex input mode
  - Disable RTS/DTR when no flow control is used
  - man page update
  - licenses cleanup
  - now builds and runs using Qt5 versions less than 5.3
  - performance tuning by switching to QPlainTextEdit
* Tue Jul  5 2016 toddrme2178@gmail.com
- Spec file cleanups:
  * Use upstream Summary
  * Use upstream Description
  * Fix Group tag
* Thu Jan 14 2016 opensuse@dstoecker.de
- update to release 0.30.2
  * custom baud rates restored properly on startup
  * custom baud rates > 200000 now selectable
  * prevent horizontal scroll bar showing up (feedback)
* Fri Dec 18 2015 cyc1ingsir@gmail.com 
- reimplementation based on Qt5
- including various feature enhancements
- removed cutecom-0.22.0-license.diff - codebase changed
- removed cutecom-0.22.0-nolinebreak.diff - codebase changed
* Tue Nov 17 2015 opensuse@dstoecker.de
- fix build for Leap 42.1
- correct FSF address
* Thu Feb 23 2012 opensuse@dstoecker.de
- display correct license in about dialog
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Tue Apr 26 2011 opensuse@dstoecker.de
- fix line breaking issue (patch copied from Debian)
* Tue Jan 27 2009 opensuse@dstoecker.de
- initial setup
